==> sdd.praapi-0.1.2-sources.jar: ar/com/sdd/praapi/model/AdditionalPartyIdentification.java <==
package ar.com.sdd.praapi.model;

import com.fasterxml.jackson.annotation.JsonIgnoreProperties;
import com.fasterxml.jackson.annotation.JsonInclude;
import com.fasterxml.jackson.annotation.JsonProperty;

import java.io.Serializable;
import java.util.Objects;

@JsonInclude(JsonInclude.Include.NON_NULL)
@JsonIgnoreProperties(ignoreUnknown = true)
public class AdditionalPartyIdentification implements Serializable {

    @JsonProperty("@additionalPartyIdentificationTypeCode")
    private String additionalPartyIdentificationTypeCode;

    @JsonProperty("#text")
    private String text;

    public String getAdditionalPartyIdentificationTypeCode() {
        return additionalPartyIdentificationTypeCode;
    }

    public void setAdditionalPartyIdentificationTypeCode(String additionalPartyIdentificationTypeCode) {
        this.additionalPartyIdentificationTypeCode = additionalPartyIdentificationTypeCode;
    }

    public String getText() {
        return text;
    }

    public void setText(String text) {
        this.text = text;
    }

    @Override
    public String toString() {
        return "AdditionalPartyIdentification [" +
                ((additionalPartyIdentificationTypeCode != null) ? "additionalPartyIdentificationTypeCode=" + additionalPartyIdentificationTypeCode + ", " : "") +
                ((text != null) ? "text=" + text + ", " : "") +
                ']';
    }

    @Override
    public boolean equals(Object o) {
        if (this == o) return true;
        if (o == null || getClass() != o.getClass()) return false;
        AdditionalPartyIdentification that = (AdditionalPartyIdentification) o;
        return Objects.equals(additionalPartyIdentificationTypeCode, that.additionalPartyIdentificationTypeCode) && Objects.equals(text, that.text);
    }

    @Override
    public int hashCode() {
        return Objects.hash(additionalPartyIdentificationTypeCode, text);
    }
}

==> sdd.praapi-0.1.7-sources.jar: ar/com/sdd/praapi/model/AdditionalPartyIdentification.java <==
package ar.com.sdd.praapi.model;

import com.fasterxml.jackson.annotation.JsonIgnoreProperties;
import com.fasterxml.jackson.annotation.JsonInclude;
import com.fasterxml.jackson.annotation.JsonProperty;

import java.io.Serializable;
import java.util.Objects;

@JsonInclude(JsonInclude.Include.NON_NULL)
@JsonIgnoreProperties(ignoreUnknown = true)
public class AdditionalPartyIdentification implements Serializable {

    @JsonProperty("@additionalPartyIdentificationTypeCode")
    private String additionalPartyIdentificationTypeCode;

    @JsonProperty("#text")
    private String text;

    public String getAdditionalPartyIdentificationTypeCode() {
        return additionalPartyIdentificationTypeCode;
    }

    public void setAdditionalPartyIdentificationTypeCode(String additionalPartyIdentificationTypeCode) {
        this.additionalPartyIdentificationTypeCode = additionalPartyIdentificationTypeCode;
    }

    public String getText() {
        return text;
    }

    public void setText(String text) {
        this.text = text;
    }

    @Override
    public String toString() {
        return "AdditionalPartyIdentification [" +
                ((additionalPartyIdentificationTypeCode != null) ? "additionalPartyIdentificationTypeCode='" + additionalPartyIdentificationTypeCode + "', " : "") +
                ((text != null) ? "text='" + text + "', " : "") +
                "]";
    }

    @Override
    public boolean equals(Object o) {
        if (this == o) return true;
        if (o == null || getClass() != o.getClass()) return false;
        AdditionalPartyIdentification that = (AdditionalPartyIdentification) o;
        return Objects.equals(additionalPartyIdentificationTypeCode, that.additionalPartyIdentificationTypeCode) && Objects.equals(text, that.text);
    }

    @Override
    public int hashCode() {
        return Objects.hash(additionalPartyIdentificationTypeCode, text);
    }
}
